@@ -13,6 +13,7 @@
 
 #include <ctype.h>
 #include <getopt.h>
+#include <limits.h>
 #include <stddef.h>
 #include <string.h>
 #include <stdlib.h>
@@ -122,6 +123,8 @@ static struct option long_options[] =
 	{"info", no_argument, 0, 56},
 	{"on-exit-sgr0", no_argument, 0, 57},
 	{"direct-color", no_argument, 0, 58},
+	{"csv-trim-width", required_argument, 0, 59},
+	{"csv-trim-rows", required_argument, 0, 60},
 	{0, 0, 0, 0}
 };
 
@@ -140,11 +143,7 @@ consume_whitespace(const char **input)
 char **
 buildargv(const char *input, int *_argc, char *appname)
 {
-	char	   *arg;
 	char	   *copybuf;
-	bool		squote = false;
-	bool		dquote = false;
-	bool		bsquote = false;
 	int			argc = 1;
 	int			maxargc = 8;
 	char	  **argv;
@@ -163,6 +162,11 @@ buildargv(const char *input, int *_argc, char *appname)
 		 */
 		do
 		{
+			char	   *arg;
+			bool		squote = false;
+			bool		dquote = false;
+			bool		bsquote = false;
+
 			/* Pick off argv[argc] */
 			consume_whitespace(&input);
 
@@ -386,6 +390,7 @@ readargs(char **argv,
 {
 	int		opt;
 	int		option_index = 0;
+	int		lopt;
 
 	state->errstr = NULL;
 
@@ -445,7 +450,7 @@ readargs(char **argv,
 					fprintf(stdout, "  --force-uniborder        replace ascii borders by unicode borders\n");
 					fprintf(stdout, "  --hide-header-line       hides header line\n");
 					fprintf(stdout, "  --highlight-odd-rec      use special style for odd records\n");
-					fprintf(stdout, "  --ignore-bad-rows        rows with wrong column numbers are ignored\n");
+					fprintf(stdout, "  --ignore-short-rows      rows with wrong column numbers are ignored\n");
 					fprintf(stdout, "  --null=STRING            STRING used instead NULL\n");
 					fprintf(stdout, "\nSearching options\n");
 					fprintf(stdout, "  -g --hlite-search, -G --HILITE-SEARCH\n");
@@ -471,6 +476,8 @@ readargs(char **argv,
 					fprintf(stdout, "  --csv-header [on/off]    specify header line usage\n");
 					fprintf(stdout, "  --skip-columns-like=\"SPACE SEPARATED STRING LIST\"\n");
 					fprintf(stdout, "                           columns with substr in name are ignored\n");
+					fprintf(stdout, "  --csv-trim-width=NUM     trim value after NUM chars\n");
+					fprintf(stdout, "  --csv-trim-rows=NUM      trim value after NUM rows\n");
 					fprintf(stdout, "  --tsv                    input stream has tsv format\n");
 					fprintf(stdout, "\nOn exit options:\n");
 					fprintf(stdout, "  --on-exit-reset          sends reset terminal sequence \"\\33c\"\n");
@@ -561,7 +568,7 @@ readargs(char **argv,
 				{
 					fprintf(stdout, "The pspg-%s is special pager designed for databases.\n\n", PSPG_VERSION);
 					fprintf(stdout, "Authors:\n");
-					fprintf(stdout, "    2017-2022 Pavel Stehule, Benesov district, Czech Republic\n\n");
+					fprintf(stdout, "    2017-2023 Pavel Stehule, Benesov district, Czech Republic\n\n");
 					fprintf(stdout, "Licence:\n");
 					fprintf(stdout, "    Distributed under BSD licence\n\n");
 
@@ -831,6 +838,27 @@ readargs(char **argv,
 
 				break;
 
+			case 59:
+				lopt = atol(optarg);
+				if (lopt < 0 || lopt > UINT_MAX)
+				{
+					state->errstr = "value for csv-trim-width is out of range (0 .. INT_MAX)";
+					return false;
+				}
+
+				opts->csv_trim_width = (unsigned int) lopt;
+				break;
+
+			case 60:
+				lopt = atol(optarg);
+				if (lopt < 0 || lopt > UINT_MAX)
+				{
+					state->errstr = "value for csv-trim-rows is out of range (0 .. INT_MAX)";
+					return false;
+				}
+
+				opts->csv_trim_rows = (unsigned int) lopt;
+				break;
 
 			default:
 				{
