@@ -3,7 +3,7 @@
  * commands.c
  *	  a list of commands and translations between keys and commands
  *
- * Portions Copyright (c) 2017-2022 Pavel Stehule
+ * Portions Copyright (c) 2017-2023 Pavel Stehule
  *
  * IDENTIFICATION
  *	  src/commands.c
@@ -23,6 +23,8 @@ int		CTRL_RIGHT;
 int		SHIFT_LEFT;
 int		SHIFT_RIGHT;
 
+#ifndef PDCURSES
+
 static int
 get_code(const char *capname, int fallback)
 {
@@ -48,6 +50,8 @@ get_code(const char *capname, int fallback)
 
 }
 
+#endif
+
 /*
  * Set a value of CTRL_HOME and CTRL_END key codes. These codes
  * can be redefined on some plaforms.
@@ -56,6 +60,19 @@ void
 initialize_special_keycodes()
 {
 
+#ifdef PDCURSES
+
+	CTRL_HOME = CTL_HOME;
+	CTRL_END = CTL_END;
+	CTRL_SHIFT_HOME = -1;
+	CTRL_SHIFT_END = -1;
+	CTRL_RIGHT = CTL_RIGHT;
+	CTRL_LEFT = CTL_LEFT;
+	SHIFT_RIGHT = KEY_SRIGHT;
+	SHIFT_LEFT = KEY_SLEFT;
+
+#else
+
 #ifdef NCURSES_EXT_FUNCS
 
 	use_extended_names(TRUE);
@@ -70,6 +87,9 @@ initialize_special_keycodes()
 	CTRL_LEFT = get_code("kLFT5", 546);
 	SHIFT_RIGHT = get_code("kRIT2", 402);
 	SHIFT_LEFT = get_code("kLFT2", 393);
+
+#endif
+
 }
 
 /*
@@ -379,6 +399,9 @@ is_cmd_RowNumToggle(int c, bool alt)
 int
 translate_event(int c, bool alt, Options *opts, int *nested_command)
 {
+	if (c == -1)
+		return cmd_Invalid;
+
 	if (alt)
 	{
 		switch (c)
@@ -499,6 +522,8 @@ translate_event(int c, bool alt, Options *opts, int *nested_command)
 			case KEY_PPAGE:
 			case 2:		/* CTRL B */
 				return cmd_PageUp;
+			case 3:		/* CTRL C */
+				return cmd_Escape;
 			case ' ':
 				return opts->watch_time > 0 ? cmd_TogglePause : cmd_PageDown;
 			case 6:		/* CTRL F */
@@ -541,6 +566,10 @@ translate_event(int c, bool alt, Options *opts, int *nested_command)
 			case '\\':
 				return cmd_BsCommand;
 
+			case 1:		/* CTRL A */
+			case '%':
+				return cmd_MarkAll;
+
 			case KEY_SR:
 				*nested_command = cmd_CursorUp;
 				return cmd_Mark_NestedCursorCommand;
